mbq.env: protect the environment
===================================

.. image:: https://img.shields.io/pypi/v/mbq.env.svg
    :target: https://pypi.python.org/pypi/mbq.env

.. image:: https://img.shields.io/pypi/l/mbq.env.svg
    :target: https://pypi.python.org/pypi/mbq.env

.. image:: https://img.shields.io/pypi/pyversions/mbq.env.svg
    :target: https://pypi.python.org/pypi/mbq.env

.. image:: https://img.shields.io/travis/managedbyq/mbq.env/master.svg
    :target: https://travis-ci.org/managedbyq/mbq.env

Installation
------------

.. code-block:: bash

    $ pip install mbq.env
    🚀✨

Guaranteed fresh.


Getting started
---------------

.. code-block:: python

    from mbq import env

    env.get('MY_KEY', default='BACON')

    # show the rest

API Reference
-------------


Contributing
------------
